## Sparky Utils

### Utility Package for Python and Django Projects

Reduce your code repetition using fine grained utility package for python and Django projects


#### Installation
```bash
pip install sparky_utils
```




